package com.iden.bms.schedule;


import com.iden.bms.face.FaceIdenService;
import com.iden.bms.service.TraceService;
import com.iden.common.cache.RedisKeyConstant;
import com.iden.common.cache.RedisUtil;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.util.UUID;

/**
 * 把预警人员的轨迹入库
 */
@Configuration
@EnableScheduling
@EnableAsync
public class WarningPersonTraceSchedule {

    @Resource
    private TraceService traceService;
    @Resource
    private RedisUtil redisUtil;

    /**
     * 把预警人员的轨迹入库
     */
    @Async
    @Scheduled(cron = "20 0/5 * * * ?")
    public void handleWarningPersonTrace() {
        String key = RedisKeyConstant.HANDLE_WARNING_PERSION_TRACE;
        String requestId = UUID.randomUUID().toString();
        boolean result = redisUtil.tryLock(key,requestId,5 * 60);
        try {
            if (result) {
                traceService.handleWarningPersonTrace();
            }
        } catch (Exception e) {
            e.getMessage();
        }  finally {
            redisUtil.releaseLock(key,requestId);
        }
    }


}
